@@ -5,7 +5,7 @@ use Text::ParseWords qw( shellwords );
 use Alien::pkgconf;
 
 my @list = (
-  $Config{cc},
+  $Config{ld},
   @ARGV,
   shellwords(Alien::pkgconf->libs),
 );
